==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkInformationExecutivePortVectorKey.java <==
// java wrapper for vtkInformationExecutivePortVectorKey object
//

package vtk;
import vtk.*;

public class vtkInformationExecutivePortVectorKey extends vtkInformationKey
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long MakeKey_2(String id0,String id1);
  public vtkInformationExecutivePortVectorKey MakeKey(String id0,String id1) {
    long temp = MakeKey_2(id0,id1);

    if (temp == 0) return null;
    return (vtkInformationExecutivePortVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Append_3(vtkInformation id0,vtkExecutive id1,int id2);
  public void Append(vtkInformation id0,vtkExecutive id1,int id2)
    { Append_3(id0,id1,id2); }

  private native void Remove_4(vtkInformation id0,vtkExecutive id1,int id2);
  public void Remove(vtkInformation id0,vtkExecutive id1,int id2)
    { Remove_4(id0,id1,id2); }

  private native int Length_5(vtkInformation id0);
  public int Length(vtkInformation id0)
    { return Length_5(id0); }

  private native void ShallowCopy_6(vtkInformation id0,vtkInformation id1);
  public void ShallowCopy(vtkInformation id0,vtkInformation id1)
    { ShallowCopy_6(id0,id1); }

  private native void Remove_7(vtkInformation id0);
  public void Remove(vtkInformation id0)
    { Remove_7(id0); }

  private native void Report_8(vtkInformation id0,vtkGarbageCollector id1);
  public void Report(vtkInformation id0,vtkGarbageCollector id1)
    { Report_8(id0,id1); }

  public vtkInformationExecutivePortVectorKey() { super(); }

  public vtkInformationExecutivePortVectorKey(long id) { super(id); }

}

==> vtk-8.2.0-20-armv7h.pkg.tar.xz: vtk/vtkInformationExecutivePortVectorKey.java <==
// java wrapper for vtkInformationExecutivePortVectorKey object
//

package vtk;
import vtk.*;

public class vtkInformationExecutivePortVectorKey extends vtkInformationKey
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long MakeKey_2(String id0,String id1);
  public vtkInformationExecutivePortVectorKey MakeKey(String id0,String id1) {
    long temp = MakeKey_2(id0,id1);

    if (temp == 0) return null;
    return (vtkInformationExecutivePortVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Append_3(vtkInformation id0,vtkExecutive id1,int id2);
  public void Append(vtkInformation id0,vtkExecutive id1,int id2)
    { Append_3(id0,id1,id2); }

  private native void Remove_4(vtkInformation id0,vtkExecutive id1,int id2);
  public void Remove(vtkInformation id0,vtkExecutive id1,int id2)
    { Remove_4(id0,id1,id2); }

  private native int Length_5(vtkInformation id0);
  public int Length(vtkInformation id0)
    { return Length_5(id0); }

  private native void ShallowCopy_6(vtkInformation id0,vtkInformation id1);
  public void ShallowCopy(vtkInformation id0,vtkInformation id1)
    { ShallowCopy_6(id0,id1); }

  private native void Remove_7(vtkInformation id0);
  public void Remove(vtkInformation id0)
    { Remove_7(id0); }

  private native void Report_8(vtkInformation id0,vtkGarbageCollector id1);
  public void Report(vtkInformation id0,vtkGarbageCollector id1)
    { Report_8(id0,id1); }

  public vtkInformationExecutivePortVectorKey() { super(); }

  public vtkInformationExecutivePortVectorKey(long id) { super(id); }

}
